@@ -91,7 +91,6 @@ load_free_pidinfos (gpointer data, gpointer user_data)
 	PidInfo *d = (PidInfo*)data;
 	
 	g_free (d->name);
-	g_free (d->load);
 }
 
 
@@ -229,7 +228,6 @@ pidui_update_load_detail (GtkTreeModel *model, GtkTreePath *path, GtkTreeIter *i
 		if ((100*(newticks-oldticks)/deltaU) < 100) {
 			str = g_strdup_printf ("%d %%", 100*(newticks-oldticks)/deltaU);
 		} else {
-			fprintf(stderr, "\tPID %d got %d as 100*(%d - %d)/%d\n", pid, newticks, oldticks, deltaU);
 			return FALSE;
 		}
 	}
