@@ -111,7 +111,7 @@ getticksforpid (gint pid)
 	if (!g_file_get_contents (statpath, &contents, &lenght, &error)) {
 		fprintf (stderr, "ERR: can't read file %s: %s\n", statpath, error->message);
 		g_error_free (error);
-		return 0;
+		return -1;
 	}
 	
 	splits = g_strsplit_set (contents, " ",  -1);
@@ -205,7 +205,6 @@ pidinfo_get_processes (int cut_from)
 	GDir *pdir = NULL;
 	const char *path;
 	gchar *full_path;
-	PidInfo* tpi;
 	
 	pdir = open_pdir ();
 	if (!pdir)
@@ -215,8 +214,7 @@ pidinfo_get_processes (int cut_from)
 		if ( g_ascii_isdigit(path[0]) == FALSE)
 			continue;	/* Skip non-process files in the directory */
 		full_path = g_strconcat (PDIR, path, "/status", NULL);
-		tpi = read_process_info (full_path);
-		if (tpi) list = g_slist_append (list, (gpointer) tpi);
+		list = g_slist_append (list, (gpointer) read_process_info (full_path));
 		g_free (full_path);
 	}
 
